@@ -9,8 +9,9 @@ class AggDeviceCapture : public AggDevice<PIXFMT> {
 public:
   bool can_capture = true;
   
-  AggDeviceCapture(const char* fp, int w, int h, double ps, int bg, double res) :
-    AggDevice<PIXFMT>(fp, w, h, ps, bg, res)
+  AggDeviceCapture(const char* fp, int w, int h, double ps, int bg, double res,
+                   double scaling) :
+    AggDevice<PIXFMT>(fp, w, h, ps, bg, res, scaling)
   {
     
   }
